@@ -467,6 +467,9 @@ class ChangePasswordView(FormView):
         user = self.request.user
         user.set_password(form.cleaned_data["password_new"])
         user.save()
+        # required on Django >= 1.7 to keep the user authenticated
+        if hasattr(auth, "update_session_auth_hash"):
+            auth.update_session_auth_hash(self.request, user)
 
     def after_change_password(self):
         user = self.request.user
